@@ -134,20 +134,20 @@ static struct {
   html_handle_emptytag_fn emptytag;
   html_handle_endtag_fn endtag;
   html_handle_endincl_fn endincl;
-} handle = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
+} h = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
 
 /* Routines to bind concrete routines to the callbacks */
-EXPORT void set_error_handler(html_handle_error_fn f) {handle.error = f;}
-EXPORT void set_start_handler(html_handle_start_fn f) {handle.start = f;}
-EXPORT void set_end_handler(html_handle_end_fn f) {handle.end = f;}
-EXPORT void set_comment_handler(html_handle_comment_fn f) {handle.comment = f;}
-EXPORT void set_text_handler(html_handle_text_fn f) {handle.text = f;}
-EXPORT void set_decl_handler(html_handle_decl_fn f) {handle.decl = f;}
-EXPORT void set_pi_handler(html_handle_pi_fn f) {handle.pi = f;}
-EXPORT void set_starttag_handler(html_handle_starttag_fn f){handle.starttag=f;}
-EXPORT void set_emptytag_handler(html_handle_emptytag_fn f){handle.emptytag=f;}
-EXPORT void set_endtag_handler(html_handle_endtag_fn f) {handle.endtag = f;}
-EXPORT void set_endincl_handler(html_handle_endincl_fn f) {handle.endincl = f;}
+EXPORT void set_error_handler(html_handle_error_fn f) {h.error = f;}
+EXPORT void set_start_handler(html_handle_start_fn f) {h.start = f;}
+EXPORT void set_end_handler(html_handle_end_fn f) {h.end = f;}
+EXPORT void set_comment_handler(html_handle_comment_fn f) {h.comment = f;}
+EXPORT void set_text_handler(html_handle_text_fn f) {h.text = f;}
+EXPORT void set_decl_handler(html_handle_decl_fn f) {h.decl = f;}
+EXPORT void set_pi_handler(html_handle_pi_fn f) {h.pi = f;}
+EXPORT void set_starttag_handler(html_handle_starttag_fn f){h.starttag = f;}
+EXPORT void set_emptytag_handler(html_handle_emptytag_fn f){h.emptytag = f;}
+EXPORT void set_endtag_handler(html_handle_endtag_fn f) {h.endtag = f;}
+EXPORT void set_endincl_handler(html_handle_endincl_fn f) {h.endincl = f;}
 
 extern int yylex(void);
 EXPORT int lineno = 1;		/* Line number in input file */
@@ -160,17 +160,18 @@ static void yyerror(const string s)
 {
   nrerrors++;
   if (nrerrors < MAX_ERRORS_REPORTED)
-    handle.error(data, s, lineno);
+    h.error(data, s, lineno);
   else if (nrerrors == MAX_ERRORS_REPORTED)
-    handle.error(data, "too many errors", lineno);
+    h.error(data, "too many errors", lineno);
   else
     ; /* don't report any more errors */
 }
 
+#define call(fn, args) (fn ? fn args : NULL)
 
 
 /* Line 189 of yacc.c  */
-#line 174 "html.c"
+#line 175 "html.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -229,7 +230,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 101 "html.y"
+#line 102 "html.y"
 
     string s;
     pairlist p;
@@ -237,7 +238,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 241 "html.c"
+#line 242 "html.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -249,7 +250,7 @@ typedef union YYSTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 253 "html.c"
+#line 254 "html.c"
 
 #ifdef short
 # undef short
@@ -540,9 +541,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   114,   114,   114,   118,   119,   120,   121,   122,   123,
-     124,   125,   126,   129,   130,   133,   134,   137,   140,   143,
-     148,   151,   152,   156
+       0,   115,   115,   115,   119,   120,   121,   122,   123,   124,
+     125,   126,   127,   130,   131,   134,   135,   138,   141,   144,
+     149,   152,   153,   157
 };
 #endif
 
@@ -1458,77 +1459,77 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 114 "html.y"
-    {data = handle.start();}
+#line 115 "html.y"
+    {data = call(h.start, ());}
     break;
 
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 115 "html.y"
-    {handle.end(data);}
+#line 116 "html.y"
+    {call(h.end, (data));}
     break;
 
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 118 "html.y"
-    {handle.comment(data, (yyvsp[(2) - (2)].s));}
+#line 119 "html.y"
+    {call(h.comment, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 119 "html.y"
-    {handle.text(data, (yyvsp[(2) - (2)].s));}
+#line 120 "html.y"
+    {call(h.text, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 123 "html.y"
-    {handle.pi(data, (yyvsp[(2) - (2)].s));}
+#line 124 "html.y"
+    {call(h.pi, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 124 "html.y"
-    {handle.endincl(data);}
+#line 125 "html.y"
+    {call(h.endincl, (data));}
     break;
 
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 129 "html.y"
-    {handle.starttag(data,(yyvsp[(1) - (3)].s),(yyvsp[(2) - (3)].p));}
+#line 130 "html.y"
+    {call(h.starttag, (data, (yyvsp[(1) - (3)].s), (yyvsp[(2) - (3)].p)));}
     break;
 
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 130 "html.y"
-    {handle.emptytag(data,(yyvsp[(1) - (3)].s),(yyvsp[(2) - (3)].p));}
+#line 131 "html.y"
+    {call(h.emptytag, (data, (yyvsp[(1) - (3)].s), (yyvsp[(2) - (3)].p)));}
     break;
 
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 133 "html.y"
+#line 134 "html.y"
     {(yyval.p) = (yyvsp[(1) - (2)].p); (yyval.p)->next = (yyvsp[(2) - (2)].p);}
     break;
 
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 134 "html.y"
+#line 135 "html.y"
     {(yyval.p) = NULL;}
     break;
 
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 137 "html.y"
+#line 138 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (1)].s);
 					 h->value=NULL; (yyval.p) = h;}
@@ -1537,7 +1538,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 140 "html.y"
+#line 141 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
 					 h->value = (yyvsp[(3) - (3)].s); (yyval.p) = h;}
@@ -1546,7 +1547,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 143 "html.y"
+#line 144 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
 					 h->value = (yyvsp[(3) - (3)].s); (yyval.p) = h;}
@@ -1555,38 +1556,38 @@ yyreduce:
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 148 "html.y"
-    {handle.endtag(data, (yyvsp[(1) - (2)].s));}
+#line 149 "html.y"
+    {call(h.endtag, (data, (yyvsp[(1) - (2)].s)));}
     break;
 
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 151 "html.y"
-    {handle.decl(data, (yyvsp[(2) - (6)].s), (yyvsp[(4) - (6)].s), (yyvsp[(5) - (6)].s));}
+#line 152 "html.y"
+    {call(h.decl, (data, (yyvsp[(2) - (6)].s), (yyvsp[(4) - (6)].s), (yyvsp[(5) - (6)].s)));}
     break;
 
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 152 "html.y"
+#line 153 "html.y"
     {if (strcasecmp((yyvsp[(3) - (5)].s), "public") == 0)
-					   handle.decl(data, (yyvsp[(2) - (5)].s), (yyvsp[(4) - (5)].s), NULL);
+				     	   call(h.decl, (data, (yyvsp[(2) - (5)].s), (yyvsp[(4) - (5)].s), NULL));
 					 else /* "system" */
-					   handle.decl(data, (yyvsp[(2) - (5)].s), NULL, (yyvsp[(4) - (5)].s));}
+					   call(h.decl, (data, (yyvsp[(2) - (5)].s), NULL, (yyvsp[(4) - (5)].s)));}
     break;
 
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 156 "html.y"
-    {handle.decl(data, (yyvsp[(2) - (3)].s), NULL, NULL);}
+#line 157 "html.y"
+    {call(h.decl, (data, (yyvsp[(2) - (3)].s), NULL, NULL));}
     break;
 
 
 
 /* Line 1455 of yacc.c  */
-#line 1590 "html.c"
+#line 1591 "html.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
