@@ -6,7 +6,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 20 Aug 2000
- * Version: $Id: hxaddid.c,v 1.2 2009/01/19 19:08:17 bbos Exp $
+ * Version: $Id: hxaddid.c,v 1.4 2011/08/26 00:29:07 bbos Exp $
  *
  **/
 #include <config.h>
@@ -177,7 +177,7 @@ Usage: %s [-x] [--] elem|.class|elem.class [html-file]\n",
 int main(int argc, char *argv[])
 {
   char *p;
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -213,10 +213,11 @@ int main(int argc, char *argv[])
   i++;
   if (i == argc) yyin = stdin;
   else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r");
+  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
