@@ -230,7 +230,7 @@ static void usage(const conststring progname)
 
 int main(int argc, char *argv[])
 {
-  int c;
+  int c, status = 200;
   string oldurl = NULL, newurl = NULL;
 
   /* Bind the parser callback routines to our handlers */
@@ -253,14 +253,15 @@ int main(int argc, char *argv[])
     default: usage(argv[0]);
     }
   if (argc > optind + 2) usage(argv[0]);
-  if (argc > optind + 1) out =  fopenurl(argv[optind+1], "w");
+  if (argc > optind + 1) out =  fopenurl(argv[optind+1], "w", NULL);
   else if (newurl) out = stdout;
   else errexit("%s: option -o is required if output is to stdout\n", argv[0]);
   if (!out) {perror(argv[optind+1]); exit(3);}
-  if (argc > optind) yyin = fopenurl(argv[optind], "r");
+  if (argc > optind) yyin = fopenurl(argv[optind], "r", &status);
   else if (oldurl) yyin = stdin;
-  else errexit("%s: option -i is required if input is from stdint\n", argv[0]);
+  else errexit("%s: option -i is required if input is from stdin\n", argv[0]);
   if (!yyin) {perror(argv[optind]); exit(2);}
+  if (status != 200) errexit("%s : %s\n", argv[1], http_strerror(status));
   if (!oldurl) oldurl = argv[optind];
   if (!newurl) newurl = argv[optind+1];
   newbase = path_from_url_to_url(newurl, oldurl);
