@@ -19,7 +19,7 @@
  *
  * Author: Bert Bos
  * Created: 2 Dec 1998
- * Version: $Id: hxincl.c,v 1.6 2010/04/26 13:14:21 bbos Exp $
+ * Version: $Id: hxincl.c,v 1.8 2011/08/26 00:29:06 bbos Exp $
  *
  **/
 #include <config.h>
@@ -152,7 +152,7 @@ void handle_comment(void *clientdata, string commenttext)
 {
   /* A push() occurs at <!--begin-include...--> and at include_file() */
   /* A pop() occurs at <!--end-include...--> and at ENDINCL */
-  int i, j;
+  int i, j, status;
   conststring s, url;
   FILE *f;
   Key key;
@@ -202,8 +202,10 @@ void handle_comment(void *clientdata, string commenttext)
 
     /* Get the file and recursively parse it */
     s = URL_s_absolutize(base, url);
-    if (!(f = fopenurl(s, "r")))
+    if (!(f = fopenurl(s, "r", &status)))
       perror(url);
+    else if (status != 200)
+      fprintf(stderr, "%s : %s\n", url, http_strerror(status));
     else {
       if (!final) printf("<!--%s %s-->", BEGIN, commenttext + i);
       push(&skipping, False);
@@ -306,7 +308,7 @@ static void usage(string prog)
 
 int main(int argc, char *argv[])
 {
-  int c;
+  int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -335,13 +337,14 @@ int main(int argc, char *argv[])
     yyin = stdin;
     base = ".";
   } else if (optind == argc - 1) {
-    yyin = fopenurl(argv[optind], "r");
+    yyin = fopenurl(argv[optind], "r", &status);
     if (!base) base = argv[optind];
   } else {
     usage(argv[0]);
   }
 
   if (yyin == NULL) {perror(argv[optind]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
