@@ -37,7 +37,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.12 2011/03/17 19:19:23 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.15 2012/03/08 22:22:20 bbos Exp $
  *
  **/
 #include <config.h>
@@ -201,7 +201,6 @@ static void handle_endtag(void *clientdata, string name)
 /* trim -- remove leading and trailing white space, collapse white space */
 static void trim(string s)
 {
-#if 1
   string t;
   int i, j;
 
@@ -214,33 +213,6 @@ static void trim(string s)
   else if (isspace(s[j-1])) s[j-1] = '\0';
   else s[j] = '\0';
   dispose(t);
-#endif
-
-#if 0
-  int i, j;
-  Boolean atspace;
-
-  atspace = True;
-  j = strlen(s);
-  i = 0;
-  while (s[i]) {
-    if (!isspace(s[i])) {atspace = False; i++;}
-    else if (!atspace) {s[i] = ' '; atspace = True; i++;}
-    else {memmove(s + i, s + i + 1, j - i); j--;}
-  }
-  if (j == 0) s[j] = '\0';
-  else if (atspace) s[j-1] = '\0';
-  else s[j] = '\0';
-#endif
-
-#if 0
-  int i, j;
-
-  for (i = 0; isspace(s[i]); i++);
-  for (j = strlen(s); j > i && isspace(s[j-1]); j--);
-  if (i != 0) memmove(s, s + i, j - i);
-  s[j-i] = '\0';
-#endif
 }
 
 /* parse_subterms -- parse s to create terms & sortkeys array in an Indexterm */
@@ -802,7 +774,7 @@ int main(int argc, char *argv[])
   Boolean write = True;
   Indexterm termtree = NULL;	/* Sorted tree of terms */
   string secno;
-  int c;
+  int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -833,9 +805,10 @@ int main(int argc, char *argv[])
   if (optind == argc) yyin = stdin;
   else if (argc > optind + 1) usage(argv[0]);
   else if (eq(argv[optind], "-")) yyin = stdin;
-  else yyin = fopenurl(argv[optind], "r");
+  else yyin = fopenurl(argv[optind], "r", &status);
 
   if (yyin == NULL) {perror(argv[optind]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
 
   if (!base) base = newstring("");
 
