@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: Dec 2004
- * Version: $Id: hxname2id.c,v 1.2 2009/01/19 19:23:51 bbos Exp $
+ * Version: $Id: hxname2id.c,v 1.4 2011/08/26 00:29:06 bbos Exp $
  *
  **/
 #include <config.h>
@@ -209,7 +209,7 @@ static void usage(string name)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -232,11 +232,9 @@ int main(int argc, char *argv[])
     } else if (eq(argv[i], "-")) {
       /* yyin = stdin; */
     } else {
-      yyin = fopenurl(argv[i], "r");
-      if (yyin == NULL) {
-	perror(argv[1]);
-	exit(2);
-      }
+      yyin = fopenurl(argv[i], "r", &status);
+      if (yyin == NULL) {perror(argv[1]); exit(2);}
+      if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
     }
   }
   if (yyparse() != 0) exit(3);
