@@ -6,7 +6,7 @@
  *
  * Created 9 May 1998
  * Bert Bos <bert@w3.org>
- * $Id: hxnormalize.c,v 1.6 2010/05/04 21:17:40 bbos Exp $
+ * $Id: hxnormalize.c,v 1.12 2012/05/02 21:52:52 bbos Exp $
  */
 #include <config.h>
 #include <stdio.h>
@@ -29,6 +29,7 @@
 #include "textwrap.e"
 #include "dict.e"
 #include "openurl.e"
+#include "errexit.e"
 
 static Tree tree;
 static Boolean do_xml = False;
@@ -37,6 +38,7 @@ static Boolean has_errors = False;
 static Boolean do_doctype = True;
 static Boolean clean_span = False;
 static string long_comment = NULL;
+static Boolean do_lang = False;
 
 
 /* handle_error -- called when a parse error occurred */
@@ -150,9 +152,11 @@ static Boolean needs_quotes(const string s)
 }
 
 /* pp -- print the document normalized */
-static void pp(Tree n, Boolean preformatted, Boolean allow_text)
+static void pp(Tree n, Boolean preformatted, Boolean allow_text,
+	       conststring lang)
 {
-  Boolean pre, mixed;
+  Boolean pre, mixed;\
+  conststring lang2;
   string s;
   pairlist h;
   size_t i;
@@ -205,28 +209,39 @@ static void pp(Tree n, Boolean preformatted, Boolean allow_text)
       if (clean_span && eq(n->name, "span") && ! n->attribs) {
 	/* Omit start and end tags, print just the children. */
 	for (l = n->children; l != NULL; l = l->sister)
-	  pp(l, preformatted, True);
+	  pp(l, preformatted, True, lang);
 	break;
       }
+      /* Determine language, remove redundant language attribute */
+      if (do_lang) {
+	if ((lang2 = pairlist_get(n->attribs, "lang")) ||
+	    (lang2 = pairlist_get(n->attribs, "xml:lang"))) {
+	  if (lang && eq(lang, lang2)) {
+	    pairlist_unset(&n->attribs, "lang");
+	    pairlist_unset(&n->attribs, "xml:lang");
+	  }
+	  lang = lang2;
+	}
+      }
       if (!preformatted && break_before(n->name)) outln(NULL, False);
       out("<", preformatted); out(n->name, preformatted);
       if (break_before(n->name)) inc_indent();
       n->attribs = sort_list(n->attribs);
       for (h = n->attribs; h != NULL; h = h->next) {
-	out(" ", preformatted); out(h->name, preformatted);
+	out(" ", False); out(h->name, False);
 	if (do_xml) {
-	  out("=\"", preformatted);
-	  out(h->value ? h->value : h->name, preformatted);
-	  outc('"', preformatted);
+	  out("=\"", False);
+	  out(h->value ? h->value : h->name, True);
+	  outc('"', False);
 	} else if (h->value == NULL) {
-	  /* Omit value */
+	  /* The h->name *is* the value (and the attribute name is implicit) */
 	} else if (!needs_quotes(h->value)) {
-	  out("=", preformatted); /* Omit the quotes */
-	  out(h->value, preformatted);
+	  out("=", False); /* Omit the quotes */
+	  out(h->value, True);
 	} else {
-	  out("=\"", preformatted);
-	  out(h->value, preformatted);
-	  outc('"', preformatted);
+	  out("=\"", False);
+	  out(h->value, True);
+	  outc('"', False);
 	}
       }
       if (is_empty(n->name)) {
@@ -239,7 +254,7 @@ static void pp(Tree n, Boolean preformatted, Boolean allow_text)
 	pre = preformatted || is_pre(n->name);
 	mixed = is_mixed(n->name);
 	for (l = n->children; l != NULL; l = l->sister)
-	  pp(l, pre, mixed);
+	  pp(l, pre, mixed, lang);
 	if (break_before(n->name)) dec_indent();
 	if (do_xml || do_endtag || need_etag(n->name) || next_ambiguous(n)) {
 	  out("</", preformatted); out(n->name, preformatted);
@@ -258,7 +273,7 @@ static void prettyprint(Tree t)
 {
   Tree h;
   assert(t->tp == Root);
-  for (h = t->children; h != NULL; h = h->sister) pp(h, False, False);
+  for (h = t->children; h != NULL; h = h->sister) pp(h, False, False, NULL);
   flush();
 }
 
@@ -266,7 +281,7 @@ static void prettyprint(Tree t)
 static void usage(string prog)
 {
   fprintf(stderr, "%s version %s\n\
-Usage: %s [-e] [-d] [-x] [-i indent] [-l linelen] [-c commentmagic] [file_or_url]\n",
+Usage: %s [-e] [-d] [-x] [-L] [-i indent] [-l linelen] [-c commentmagic] [file_or_url]\n",
 	  prog, VERSION, prog);
   exit(1);
 }
@@ -274,7 +289,7 @@ Usage: %s [-e] [-d] [-x] [-i indent] [-l linelen] [-c commentmagic] [file_or_url
 /* main -- main body */
 int main(int argc, char *argv[])
 {
-  int c;
+  int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -288,7 +303,7 @@ int main(int argc, char *argv[])
   set_emptytag_handler(handle_emptytag);
   set_endtag_handler(handle_endtag);
 
-  while ((c = getopt(argc, argv, "edxi:l:sc:")) != -1)
+  while ((c = getopt(argc, argv, "edxi:l:sc:L")) != -1)
     switch (c) {
     case 'e': do_endtag = True; break;
     case 'x': do_xml = True; break;
@@ -297,12 +312,14 @@ int main(int argc, char *argv[])
     case 'l': set_linelen(atoi(optarg)); break;
     case 's': clean_span = True; break;
     case 'c': long_comment = optarg; break;
+    case 'L': do_lang = True; break;
     default: usage(argv[0]);
     }
   if (optind == argc) yyin = stdin;
-  else if (optind == argc - 1) yyin = fopenurl(argv[optind], "r");
+  else if (optind == argc - 1) yyin = fopenurl(argv[optind], "r", &status);
   else usage(argv[0]);
   if (yyin == NULL) {perror(argv[optind]); exit(2);}
+  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
   if (yyparse() != 0) {exit(3);}
   tree = get_root(tree);
   prettyprint(tree);
