@@ -8,7 +8,7 @@
  *
  * Bert Bos
  * Created Sep 1997
- * $Id: hxnum.c,v 1.2 2009/01/09 20:34:28 bbos Exp $
+ * $Id: hxnum.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
  */
 #include <config.h>
 #include <stdio.h>
@@ -36,6 +36,7 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
+#include "errexit.e"
 
 #define SECNO "secno"				/* class attribute */
 #define NO_NUM "no-num"				/* class-attribute */
@@ -244,7 +245,7 @@ static void help(void)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -291,10 +292,11 @@ int main(int argc, char *argv[])
 
   if (i == argc) yyin = stdin;
   else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r");
+  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) {
     exit(3);
