@@ -72,7 +72,7 @@
  *
  * Author: Bert Bos
  * Created: 2 Dec 1998
- * Version: $Id: hxpipe.c,v 1.2 2009/01/08 14:36:13 bbos Exp $
+ * Version: $Id: hxpipe.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
  *
  **/
 #include <config.h>
@@ -97,6 +97,7 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
+#include "errexit.e"
 
 #define XMLID "{http://www.w3.org/XML/1998/namespace}id"
 
@@ -246,7 +247,7 @@ static void usage(string prog)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -271,10 +272,11 @@ int main(int argc, char *argv[])
 
   if (i == argc) yyin = stdin;
   else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r");
+  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
