@@ -6,7 +6,7 @@
  *
  * Bert Bos <bert@w3.org>
  * Created Feb 2000
- * $Id: hxprune.c,v 1.2 2009/01/19 19:22:31 bbos Exp $
+ * $Id: hxprune.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
  *
  **/
 /* #include <mcheck.h> */
@@ -35,6 +35,7 @@
 #include "dict.e"
 #include "openurl.e"
 #include "class.e"
+#include "errexit.e"
 
 #define EXCLUDE_CLASS "exclude"			/* Default value for class */
 
@@ -164,7 +165,7 @@ static void usage(string name)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status;
   string class = EXCLUDE_CLASS;
 
   /*  mtrace(); */
@@ -189,11 +190,9 @@ int main(int argc, char *argv[])
     } else if (eq(argv[i], "-x")) {
       xml = True;
     } else {
-      yyin = fopenurl(argv[i], "r");
-      if (yyin == NULL) {
-	perror(argv[1]);
-	exit(2);
-      }
+      yyin = fopenurl(argv[i], "r", &status);
+      if (yyin == NULL) {perror(argv[1]); exit(2);}
+      if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
     }
   }
 
