@@ -22,7 +22,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 4 August 2000
- * Version: $Id: hxref.c,v 1.5 2010/11/17 22:40:01 bbos Exp $
+ * Version: $Id: hxref.c,v 1.8 2012/03/08 22:20:37 bbos Exp $
  **/
 
 #include <config.h>
@@ -70,6 +70,7 @@
 static Tree tree;
 static string base = NULL, progname;
 static Boolean do_xml = False;
+static Boolean use_language = False;
 
 
 /* handle_error -- called when a parse error occurred */
@@ -208,6 +209,55 @@ static string normalize(string s)
 }
 
 
+/* search -- search a matching string in the hash table */
+static ENTRY* search(string key, const conststring language)
+{
+  ENTRY entry, *e;
+  int n;
+  string t;
+
+  /* Assumes key has already passed normalize() */
+
+  /* First try the key as it is */
+  entry.key = key;
+  if ((e = hsearch(entry, FIND))) return e;
+
+  /* Should we try language-specific modifications to the key? */
+  if (!language || !use_language) return NULL;
+
+  if (eq(language, "en") || hasprefix(language, "en-")) { /* English */
+
+    /* Remove plural s */
+    if ((n = strlen(key)) > 1 && key[n-1] == 's' && islower(key[n-2])) {
+      t = newnstring(key, n - 1);
+      entry.key = t;
+      e = hsearch(entry, FIND);
+      dispose(t);
+      if (e) return e;
+    }
+    /* Remove plural es */
+    if (n > 2 && key[n-1] == 's' && key[n-2] == 'e' && islower(key[n-3])) {
+      t = newnstring(key, n - 2);
+      entry.key = t;
+      e = hsearch(entry, FIND);
+      dispose(t);
+      if (e) return e;
+    }
+    /* Replace plural ies by singular y */
+    if (n > 3 && hasaffix(key, "ies") && islower(key[n-4])) {
+      t = newnstring(key, n - 3);
+      strapp(&t, "y", NULL);
+      entry.key = t;
+      e = hsearch(entry, FIND);
+      dispose(t);
+      if (e) return e;
+    }
+  }
+
+  return NULL;
+}
+
+
 /* collect_terms -- walk the document tree looking for <dfn> elements */
 static void collect_terms(Tree tree, FILE *db)
 {
@@ -261,22 +311,26 @@ static void collect_terms(Tree tree, FILE *db)
 
 
 /* find_instances -- walk tree, make instances of defined terms into links */
-static void find_instances(Tree tree)
+static void find_instances(Tree tree, const conststring language)
 {
-  ENTRY entry, *e;
-  conststring title;
+  ENTRY *e;
+  conststring title, lang;
+  string key;
 
   if (!tree) return;
 
   switch (tree->tp) {
     case Text: case Comment: case Declaration: case Procins:
-      find_instances(tree->sister);
+      find_instances(tree->sister, language);
       break;
     case Root:
-      find_instances(tree->children);		/* Recurse over children */
-      find_instances(tree->sister);		/* Recurse over siblings */
+      find_instances(tree->children, language);	/* Recurse over children */
+      find_instances(tree->sister, language);	/* Recurse over siblings */
       break;
     case Element:
+      if (!(lang = get_attrib(tree, "lang")) &&
+	  !(lang = get_attrib(tree, "xml:lang")))
+	lang = language;
       if (eq(tree->name, "a") || eq(tree->name, "dfn"))
 	;					/* Don't descend into these */
       else if (eq(tree->name, "abbr") || eq(tree->name, "acronym")
@@ -292,11 +346,11 @@ static void find_instances(Tree tree)
 	       || eq(tree->name, "sub") || eq(tree->name, "sup")
 	       || eq(tree->name, "tt") || eq(tree->name, "var")) {
 	if ((title = get_attrib(tree, "title"))) /* Use title if it exists */
-	  entry.key = normalize(newstring(title));
+	  key = newstring(title);
 	else					/* Get flattened contents */
-	  entry.key = normalize(get_contents(tree));
-	if (! (e = hsearch(entry, FIND))) {	/* If not an instance */
-	  find_instances(tree->children);	/* Recurse over children */
+	  key = get_contents(tree);
+	if (!(e = search(normalize(key), lang))) { /* If not an instance */
+	  find_instances(tree->children, lang); /* Recurse over children */
 	} else if (eq(tree->name, "span")) {	/* Found an instance */
 	  rename_elt(tree, "a");		/* Turn the span into an a */
 	  set_attrib(tree, "href", e->data);
@@ -304,11 +358,11 @@ static void find_instances(Tree tree)
 	  tree = wrap_elt(tree, "a", NULL);	/* Wrap element in an <a> */
 	  set_attrib(tree, "href", e->data);
 	}
-	dispose(entry.key);
+	dispose(key);
       } else {					/* Not an inline element */
-	find_instances(tree->children);		/* Recurse over children */
+	find_instances(tree->children, lang);	/* Recurse over children */
       }
-      find_instances(tree->sister);		/* Recurse over siblings */
+      find_instances(tree->sister, language);	/* Recurse over siblings */
       break;
     default:
       assert(!"Cannot happen");
@@ -367,7 +421,7 @@ static void write_doc(Tree n, Boolean do_xml, FILE *f)
 static void usage(void)
 {
   fprintf(stderr,
-	  "Version %s\nUsage: %s [-b base] [-i index] [-x] [--] [input [output]]\n",
+	  "Version %s\nUsage: %s [-b base] [-i index] [-x] [-l] [--] [input [output]]\n",
 	  VERSION, progname);
   exit(1);
 }
@@ -376,7 +430,7 @@ static void usage(void)
 /* main -- main body of xref */
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
   FILE *outfile = NULL, *db = NULL;
 
   /* Bind the parser callback routines to our handlers */
@@ -411,6 +465,10 @@ int main(int argc, char *argv[])
 	db = fopen(argv[i][2] ? argv[i] + 2 : argv[++i], "a+");
 	if (! db) errexit("%s: %s\n", argv[i], strerror(errno));
 	break;
+      case 'l':
+	if (use_language) usage(); 		/* Option was already set */
+	use_language = True;
+	break;
       case '\0':
 	if (!yyin) yyin = stdin;
 	else if (!outfile) outfile = stdout;
@@ -425,8 +483,9 @@ int main(int argc, char *argv[])
   if (i < argc) {
     if (yyin) usage();				/* Input was already set */
     if (eq(argv[i], "-")) yyin = stdin;
-    else yyin = fopenurl(argv[i], "r");
+    else yyin = fopenurl(argv[i], "r", &status);
     if (! yyin) errexit("%s: %s\n", argv[i], strerror(errno));
+    if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
   }
   if (++i < argc) {
     if (outfile) usage();			/* Output was already set */
@@ -452,7 +511,7 @@ int main(int argc, char *argv[])
   
   tree = get_root(tree);
   collect_terms(tree, db);
-  find_instances(tree);
+  find_instances(tree, NULL);
 
   if (db) fclose(db);
 
