@@ -23,7 +23,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created Sep 1997
- * Version: $Id: hxtoc.c,v 1.3 2009/01/19 19:17:49 bbos Exp $
+ * Version: $Id: hxtoc.c,v 1.5 2011/08/26 00:29:06 bbos Exp $
  *
  **/
 #include <config.h>
@@ -412,7 +412,7 @@ static void usage(string name)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status;
   Boolean write = True;
 
   /* Bind the parser callback routines to our handlers */
@@ -447,11 +447,9 @@ int main(int argc, char *argv[])
       if (i >= argc - 1) usage(argv[0]);
       toc_class = newstring(argv[++i]);
     } else {
-      yyin = fopenurl(argv[i], "r");
-      if (yyin == NULL) {
-	perror(argv[1]);
-	exit(2);
-      }
+      yyin = fopenurl(argv[i], "r", &status);
+      if (yyin == NULL) {perror(argv[i]); exit(2);}
+      if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
     }
   }
   if (toc_low < 1) toc_low = 1;
