@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos
  * Created: 8 November 2005
- * Version: $Id: hxunxmlns.c,v 1.1 2008/08/17 13:55:39 bbos Exp $
+ * Version: $Id: hxunxmlns.c,v 1.4 2011/08/26 20:41:01 bbos Exp $
  *
  **/
 #include <config.h>
@@ -36,6 +36,7 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
+#include "errexit.e"
 
 
 #define XMLNS "{http://www.w3.org/XML/1998/namespace}"
@@ -186,7 +187,7 @@ static void usage(string prog)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -210,10 +211,11 @@ int main(int argc, char *argv[])
 
   if (i == argc) yyin = stdin;
   else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r");
+  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
