@@ -6,7 +6,7 @@
  *
  * Bert Bos <bert@w3.org>
  * Created 31 July 1999
- * $Id: hxwls.c,v 1.2 2009/01/19 19:15:35 bbos Exp $
+ * $Id: hxwls.c,v 1.4 2011/08/26 20:41:01 bbos Exp $
  */
 #include <config.h>
 #include <assert.h>
@@ -32,6 +32,7 @@
 #include "dict.e"
 #include "openurl.e"
 #include "url.e"
+#include "errexit.e"
 
 static Boolean has_error = False;
 static string base = NULL;
@@ -215,7 +216,7 @@ static void usage(string progname)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -247,13 +248,15 @@ int main(int argc, char *argv[])
     self = "-";
   } else if (i == argc - 1) {
     if (!base) base = strdup(argv[i]);
-    if (eq(argv[i], "-")) yyin = stdin; else yyin = fopenurl(argv[i], "r");
+    if (eq(argv[i], "-")) yyin = stdin;
+    else yyin = fopenurl(argv[i], "r", &status);
     self = argv[i];
   } else {
     usage(argv[0]);
   }
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
