@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos
  * Created: 22 Mar 2000
- * Version: $Id: hxxmlns.c,v 1.2 2010/07/12 17:26:33 bbos Exp $
+ * Version: $Id: hxxmlns.c,v 1.5 2011/08/26 20:41:40 bbos Exp $
  *
  **/
 #include <config.h>
@@ -37,6 +37,7 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
+#include "errexit.e"
 
 extern int yylineno;				/* From scan.l */
 
@@ -253,7 +254,7 @@ static void usage(string prog)
 
 int main(int argc, char *argv[])
 {
-  int i;
+  int i, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -277,10 +278,11 @@ int main(int argc, char *argv[])
   if (i < argc && eq(argv[i], "--")) i++;
 
   if (i == argc) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r");
+  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
   if (yyin == NULL) {perror(argv[i]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
